@@ -4,6 +4,7 @@
 #include <EGL/egl.h>
 #include <xf86drmMode.h>
 #include <SRMTypes.h>
+#include <gbm.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -14,7 +15,8 @@ enum SRM_ATOMIC_CHANGE
     SRM_ATOMIC_CHANGE_CURSOR_VISIBILITY = 1 << 0,
     SRM_ATOMIC_CHANGE_CURSOR_POSITION   = 1 << 1,
     SRM_ATOMIC_CHANGE_CURSOR_BUFFER     = 1 << 2,
-    SRM_ATOMIC_CHANGE_GAMMA_LUT         = 1 << 3
+    SRM_ATOMIC_CHANGE_GAMMA_LUT         = 1 << 3,
+    SRM_ATOMIC_CHANGE_CONTENT_TYPE      = 1 << 4
 };
 
 Int8  srmRenderModeCommonMatchConfigToVisual(EGLDisplay egl_display, EGLint visual_id, EGLConfig *configs, int count);
@@ -29,10 +31,13 @@ Int32 srmRenderModeAtomicCommit(Int32 fd, drmModeAtomicReqPtr req, UInt32 flags,
 Int32 srmRenderModeCommonInitCrtc(SRMConnector *connector, UInt32 fb);
 void srmRenderModeCommonPauseRendering(SRMConnector *connector);
 void srmRenderModeCommonResumeRendering(SRMConnector *connector, UInt32 fb);
+void srmRenderModeCommonSyncState(SRMConnector *connector);
 void srmRenderModeCommonUninitialize(SRMConnector *connector);
 Int32 srmRenderModeCommonUpdateMode(SRMConnector *connector, UInt32 fb);
 void srmRenderModeCommonPageFlip(SRMConnector *connector, UInt32 fb);
 void srmRenderModeCommonWaitPageFlip(SRMConnector *connector, Int32 iterLimit);
+void srmRenderModeCommonSearchNonLinearModifier(SRMConnector *connector);
+void srmRenderModeCommonCreateConnectorGBMSurface(SRMConnector *connector, struct gbm_surface **surface);
 
 #ifdef __cplusplus
 }
